@@ -1,4 +1,6 @@
 # pylint: disable=wildcard-import
+import os
+
 from .base import *  # noqa
 
 
@@ -7,3 +9,5 @@ ENVIRONMENT = "github_action"
 CELERY_TASK_ALWAYS_EAGER = True
 
 LOGGING["root"]["level"] = "INFO"  # noqa
+
+GITHUB_TOKEN = os.environ["GITHUB_TOKEN"]
