@@ -7,6 +7,7 @@ from typing import Tuple
 
 import jwt
 import requests
+from django.conf import settings
 from django.core.cache import cache
 from django.utils.timezone import now
 from github import Github
@@ -236,6 +237,11 @@ class GitHubInstallationClient(InstallationClient):
         return token
 
 
+class GitHubActionInstallationClient(GitHubInstallationClient):
+    def _get_installation_token(self):
+        return settings.GITHUB_TOKEN
+
+
 def _gen_jwt():
     private_key = os.getenv("GITHUB_APP_PRIVATE_KEY").replace("\\n", "\n")
     return jwt.encode(
